DateTime

Struct DateTime 

pub struct DateTime {
    pub date: Date,
    pub time: Time,
}
Combines a simple date and time.

Fields

date: Date

The date part of this date and time.

time: Time

The time part of this date and time.

Implementations

Source

impl DateTime

pub fn new(date: Date, time: Time) -> Self

Create a new DateTime from a Date and Time.

pub fn year(&self) -> u16

Return the year of the date.

pub fn month(&self) -> u8

Return the month of the date [1-12].

pub fn day(&self) -> u8

Return the day of the month for this date [1-31].

pub fn hour(&self) -> u8

Read the hour of the time [0-23].

pub fn minute(&self) -> u8

Read the minute of the time [0-59].

pub fn second(&self) -> u8

Read the second of the time [0-60].

A value of 60 might occur on a leap second.

pub fn weekday(&self) -> Weekday

Compute the weekday of the date.

This is guaranteed to work for all valid dates within the years 2000 to 2171.

Invalid dates will return arbitrary results or may panic.