pub struct Time {
pub hour: u8,
pub minute: u8,
pub second: u8,
}Expand description
A simple time of a day.
Fields
hour: u8Hour of the day [0-23].
minute: u8Minute of the hour [0-59].
second: u8Second of the minute [0-60].
A value of 60 might occur on a leap second.
Implementations
Sourceimpl Time
impl Time
Sourcepub fn new(hour: u8, minute: u8, second: u8) -> Self
pub fn new(hour: u8, minute: u8, second: u8) -> Self
Create a new Time from hours, minutes and seconds.
No checks will be performed to validate the time.