Fundamental primitives to communicate date and time information.
The focus of this implementation is to be lightweight and easy to use so that it can be used on resource-constrained embedded systems. Only basic checks will be performed for the reasonable use-cases.
Structs
- Date
- A simple date in the Gregorian calendar without time zone information.
- Date
Time - Combines a simple date and time.
- Time
- A simple time of a day.
Enums
- Weekday
- Day of the week starting from Monday = 1 (ISO 8601).