Weekday

Enum Weekday 

#[repr(u8)]
pub enum Weekday { Mon = 1, Tue = 2, Wed = 3, Thu = 4, Fri = 5, Sat = 6, Sun = 7, }
Day of the week starting from Monday = 1 (ISO 8601).

The ordinal value of 0 is not being used by common RTC chips. This place can be used to re-map Sunday to 0 in order to obtain a week starting from Sunday.

PartialOrd isn’t implemented on purpose because weekdays are usually used in a cyclic manner.

Variants



Mon = 1

Monday.



Tue = 2

Tuesday.



Wed = 3

Wednesday.



Thu = 4

Thursday.



Fri = 5

Friday.



Sat = 6

Saturday.



Sun = 7

Sunday.

Implementations

Source

impl Weekday

pub const MON_NUM: u8 = 1

the numeric code being used for Monday.

pub const TUE_NUM: u8 = 2

the numeric code being used for Tuesday.

pub const WED_NUM: u8 = 3

the numeric code being used for Wednesday.

pub const THU_NUM: u8 = 4

the numeric code being used for Thursday.

pub const FRI_NUM: u8 = 5

the numeric code being used for Friday.

pub const SAT_NUM: u8 = 6

the numeric code being used for Saturday.

pub const SUN_NUM: u8 = 7

the numeric code being used for Sunday.

pub const MON: &str = "Mon"

the short name of Monday in English.

pub const TUE: &str = "Tue"

the short name of Tuesday in English.

pub const WED: &str = "Wed"

the short name of Wednesday in English.

pub const THU: &str = "Thu"

the short name of Thursday in English.

pub const FRI: &str = "Fri"

the short name of Friday in English.

pub const SAT: &str = "Sat"

the short name of Saturday in English.

pub const SUN: &str = "Sun"

the short name of Sunday in English.

pub fn num_days_from_monday(self) -> u8

Returns a day-of-week number starting from Monday = 0.

pub fn number_from_monday(self) -> u8

Returns a day-of-week number starting from Monday = 1.

pub fn num_days_from_sunday(self) -> u8

Returns a day-of-week number starting from Sunday = 0.

pub fn number_from_sunday(self) -> u8

Returns a day-of-week number starting from Sunday = 1.

pub fn as_str(self) -> &'static str

Return the weekday’s short name in English.

The returned string is guaranteed to be 3 characters long.