Struct DateTime
Source pub struct DateTime {
pub date: Date,
pub time: Time,
}
Combines a simple date and time.
The date part of this date and time.
The time part of this date and time.
Create a new DateTime from a Date and Time.
Return the year of the date.
Return the month of the date [1-12].
Return the day of the month for this date [1-31].
Read the hour of the time [0-23].
Read the minute of the time [0-59].
Read the second of the time [0-60].
A value of 60 might occur on a leap second.
Compute the weekday of the date.
This is guaranteed to work for all valid dates within the years 2000 to 2171.
Invalid dates will return arbitrary results or may panic.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Formats the value using the given formatter.
Read more
Compares and returns the maximum of two values.
Read more
Compares and returns the minimum of two values.
Read more
Restrict a value to a certain interval.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
This method returns an ordering between
self and
other values if one exists.
Read more
Tests less than (for
self and
other) and is used by the
< operator.
Read more
Tests less than or equal to (for
self and
other) and is used by the
<= operator.
Read more
Tests greater than (for
self and
other) and is used by the
>
operator.
Read more
Tests greater than or equal to (for
self and
other) and is used by
the
>= operator.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.